"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var delayed_changes_field_plugin_1 = require("../../field/field/plugin/delayed-changes-field.plugin");
var generic_component_1 = require("../../base/generic.component");
var definition_1 = require("../../../definition");
var button_1 = require("../../button");
var text_field_1 = require("../../field/text-field");
var flex_layout_component_1 = require("../../layout/flex/flex-layout.component");
var SearchToolbar = /** @class */ (function (_super) {
    __extends(SearchToolbar, _super);
    /**
     * @stable [22.04.2020]
     * @param {TProps} props
     */
    function SearchToolbar(props) {
        var _a;
        var _this = _super.call(this, props) || this;
        /**
         * @stable [22.04.2020]
         */
        _this.baseActionsProps = (_a = {},
            _a[definition_1.ToolbarToolsEnum.CLEAR] = { type: definition_1.IconsEnum.TIMES, onClick: _this.onDeactivate.bind(_this) },
            _a[definition_1.ToolbarToolsEnum.DOWNLOAD_FILE] = { type: definition_1.IconsEnum.FILE_DOWNLOAD, title: _this.settings.messages.EXPORT },
            _a[definition_1.ToolbarToolsEnum.FILTER] = { type: definition_1.IconsEnum.FILTER, onClick: _this.onOpen.bind(_this) },
            _a[definition_1.ToolbarToolsEnum.REFRESH] = { type: definition_1.IconsEnum.SYNC, title: _this.settings.messages.REFRESH },
            _a);
        _this.onActivate = _this.onActivate.bind(_this);
        _this.onApply = _this.onApply.bind(_this);
        _this.onChange = _this.onChange.bind(_this);
        return _this;
    }
    SearchToolbar.prototype.render = function () {
        var props = this.props;
        return (React.createElement(flex_layout_component_1.FlexLayout, { row: true, justifyContentEnd: true, alignItemsCenter: true, full: props.full, className: util_1.joinClassName(definition_1.ToolbarClassesEnum.SEARCH_TOOLBAR, util_1.calc(props.className)) },
            this.actionsElementsSection,
            this.fieldSection));
    };
    Object.defineProperty(SearchToolbar.prototype, "isActive", {
        /**
         * @stable [18.05.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.active;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchToolbar.prototype, "query", {
        /**
         * @stable [18.05.2018]
         * @returns {string}
         */
        get: function () {
            return this.props.query;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [18.05.2018]
     */
    SearchToolbar.prototype.onActivate = function () {
        var props = this.props;
        if (props.notUseField) {
            // Invoke a search
            this.onApply();
        }
        else {
            if (props.onActivate) {
                // Open a search field
                props.onActivate();
            }
        }
    };
    /**
     * @stable [18.05.2018]
     */
    SearchToolbar.prototype.onDeactivate = function () {
        var props = this.props;
        if (props.onDeactivate) {
            // Close a search field
            props.onDeactivate();
        }
    };
    /**
     * @stable [18.05.2018]
     * @param {string} query
     */
    SearchToolbar.prototype.onChange = function (query) {
        var props = this.props;
        if (props.onChange) {
            props.onChange(query);
        }
    };
    Object.defineProperty(SearchToolbar.prototype, "fieldProps", {
        /**
         * @stable [18.05.2018]
         * @returns {IUniversalFieldProps}
         */
        get: function () {
            var props = this.props;
            return __assign({ autoFocus: true, errorMessageRendered: false, value: this.query, actions: this.actions, onChange: this.onChange, onDelay: this.onApply, plugins: delayed_changes_field_plugin_1.DelayedChangesFieldPlugin }, props.fieldConfiguration);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchToolbar.prototype, "actions", {
        // TODO
        get: function () {
            var _this = this;
            var props = this.props;
            var defaultActions = props.notUseField
                ? []
                : [{ type: definition_1.ToolbarToolsEnum.CLEAR }];
            return R.map(function (action) {
                var config = _this.baseActionsProps[action.type];
                return (__assign({}, config, { disabled: util_1.nvl(action.disabled, props.actionsDisabled), className: action.className }));
            }, defaultActions.concat(props.actions));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchToolbar.prototype, "actionsElements", {
        /**
         * @stable [18.05.2018]
         * @returns {JSX.Element[]}
         */
        get: function () {
            var _this = this;
            var actions;
            var props = this.props;
            return []
                .concat(this.isActive
                ? []
                : this.getActionElement({
                    key: 'toolbar-action-key',
                    icon: props.icon,
                    onClick: this.onActivate,
                    disabled: props.actionsDisabled,
                })).concat(props.notUseField && (actions = this.actions).length > 0
                ? actions.map(function (action, index) { return _this.getActionElement(__assign({}, action, { icon: action.type, key: "toolbar-action-key-" + index, disabled: props.actionsDisabled, className: action.className })); })
                : []);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchToolbar.prototype, "fieldSection", {
        /**
         * @stable [18.05.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return util_1.orNull(this.isActive, function () { return _this.fieldWrapper; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchToolbar.prototype, "actionsElementsSection", {
        /**
         * @stable [18.05.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return util_1.orNull(this.actionsElements.length > 0, function () { return _this.actionsElementsWrapper; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchToolbar.prototype, "actionsElementsWrapper", {
        /**
         * @stable [18.05.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            return this.actionsElements;
        },
        enumerable: true,
        configurable: true
    });
    SearchToolbar.prototype.getActionElement = function (config) {
        return React.createElement(button_1.Button, __assign({}, config)); // TODO
    };
    Object.defineProperty(SearchToolbar.prototype, "fieldWrapper", {
        /**
         * @stable [18.05.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(text_field_1.TextField, __assign({}, this.fieldProps)));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [18.05.2018]
     */
    SearchToolbar.prototype.onOpen = function () {
        var props = this.props;
        if (props.onOpen) {
            props.onOpen();
        }
    };
    /**
     * @stable [18.05.2018]
     */
    SearchToolbar.prototype.onApply = function () {
        var props = this.props;
        if (props.onApply) {
            props.onApply();
        }
    };
    /**
     * @stable [18.05.2018]
     */
    SearchToolbar.defaultProps = {
        actions: [],
        icon: 'search',
        fieldConfiguration: {
            placeholder: 'Search',
        },
    };
    return SearchToolbar;
}(generic_component_1.GenericComponent));
exports.SearchToolbar = SearchToolbar;
//# sourceMappingURL=search-toolbar.component.js.map