import { DatesRangeValueT, IDatesRangeEntity, IExtendedLabeledValueEntity, IFieldConverter, IFieldConverterConfigEntity, INamedEntity, IPlaceEntity, IUserEntity, SelectValueT, TranslatorT } from '../../definition';
import { AnyT, EntityIdT, StringNumberT } from '../../definitions.interface';
export declare class FieldConverter implements IFieldConverter {
    private static readonly logger;
    protected readonly t: TranslatorT;
    protected readonly converters: Map<string, (value: any) => any>;
    /**
     * @stable [09.01.2020]
     */
    constructor();
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     */
    register(config: IFieldConverterConfigEntity): void;
    /**
     * @stable [24.12.2019]
     * @param {IPhoneConfigEntity<libphonenumber.PhoneNumberFormat>} config
     * @returns {string}
     */
    convert(config: IFieldConverterConfigEntity): AnyT;
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {(value: AnyT) => AnyT}
     */
    converter(config: IFieldConverterConfigEntity): (value: AnyT) => AnyT;
    /**
     * @stable [14.03.2020]
     * @param {TValue} value
     * @returns {IUserEntity}
     */
    fromOAuthJwtDecodedInfoToUserEntity<TValue = AnyT>(value: TValue): IUserEntity;
    /**
     * @stable [22.04.2020]
     * @param {INamedEntity} value
     * @returns {IExtendedLabeledValueEntity}
     */
    fromNamedEntityToExtendedLabeledValueEntity(value: INamedEntity): IExtendedLabeledValueEntity;
    /**
     * @stable [13.04.2020]
     * @nullable
     * @param {string} value
     * @returns {string}
     */
    fromCronExpressionToCronParameter(value: string): string;
    /**
     * @stable [28.01.2020]
     * @param {IPlaceEntity | string} placeEntity
     * @returns {string}
     */
    protected placeEntityAsDisplayValue(placeEntity: IPlaceEntity | string): string;
    /**
     * @stable [28.01.2020]
     * @param {IPlaceEntity | string} placeEntity
     * @returns {string}
     */
    protected zipCodeEntityAsDisplayValue(placeEntity: IPlaceEntity | string): string;
    /**
     * @stable [28.01.2020]
     * @param {SelectValueT} option
     * @returns {StringNumberT}
     */
    protected selectOptionEntityAsDisplayValue(option: SelectValueT): StringNumberT;
    /**
     * @stable [28.01.2020]
     * @param {SelectValueT} option
     * @returns {EntityIdT}
     */
    protected selectOptionEntityAsId(option: SelectValueT): EntityIdT;
    /**
     * @stable [07.03.2020]
     * @param {IDatesRangeEntity} entity
     * @returns {DatesRangeValueT}
     */
    protected datesRangeEntityAsDatesRangeValue(entity: IDatesRangeEntity): DatesRangeValueT;
    /**
     * @stable [07.03.2020]
     * @param {DatesRangeValueT} value
     * @returns {IDatesRangeEntity}
     */
    protected datesRangeValueAsDatesRangeEntity(value: DatesRangeValueT): IDatesRangeEntity;
    /**
     * @stable [14.03.2020]
     * @param {TValue} value
     * @returns {IUserEntity}
     */
    private $fromOAuthJwtDecodedInfoToUserEntity;
    /**
     * @stable [13.04.2020]
     * @nullable
     * @param {string} value
     * @returns {string}
     */
    private $fromCronExpressionToCronParameter;
    /**
     * @stable [22.04.2020]
     * @param {INamedEntity} value
     * @returns {IExtendedLabeledValueEntity}
     */
    private $fromNamedEntityToExtendedLabeledValueEntity;
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {string}
     */
    private asKey;
}
