"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var wrapper_1 = require("./wrapper");
var type_1 = require("./type");
var nvl_1 = require("./nvl");
var mapper_1 = require("./mapper");
var tab_1 = require("./tab");
var select_1 = require("./select");
var object_1 = require("./object");
/**
 * @stable [06.05.2020]
 * @param {IBaseExtendedFormEditableEntity<TEntity>} wrapper
 * @param {string} fieldName
 * @returns {AnyT}
 */
var getFieldValueByName = function (wrapper, fieldName) { return (cond_1.ifNotEmptyThanValue(fieldName, function () { return (cond_1.ifNotNilThanValue((R.isNil(wrapper.entity)
    ? select_1.Selectors.formEditableEntityChanges(wrapper)
    : wrapper.entity), function (data) { return data[fieldName]; }, definitions_interface_1.UNDEF_SYMBOL)); }, definitions_interface_1.UNDEF_SYMBOL)); };
/**
 * @stable [06.05.2020]
 * @param {IBaseExtendedFormEditableEntity<TEntity>} wrapper
 * @param {IGenericFieldEntity} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldValue = function (wrapper, fieldProps) {
    return type_1.isDef(fieldProps.value)
        ? fieldProps.value
        : getFieldValueByName(wrapper, fieldProps.name);
};
/**
 * @stable [06.05.2020]
 * @param {IBaseExtendedFormEditableEntity<TEntity>} wrapper
 * @param {IGenericFieldEntity} fieldProps
 * @param {IGenericFieldEntity} defaultFieldProps
 * @returns {AnyT}
 */
exports.getFormFieldDisplayValue = function (wrapper, fieldProps, defaultFieldProps) {
    return type_1.isDef(fieldProps.displayValue)
        ? fieldProps.displayValue
        : (getFieldValueByName(wrapper, fieldProps.displayName || cond_1.ifNotNilThanValue(defaultFieldProps, function () { return defaultFieldProps.displayName; })));
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @param {IGenericFieldEntity} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldOriginalValue = function (entity, fieldProps) {
    return type_1.isDef(fieldProps.originalValue)
        ? fieldProps.originalValue
        : (cond_1.ifNotNilThanValue(entity.originalEntity, function (originalEntity) {
            return cond_1.ifNotEmptyThanValue(fieldProps.name, function (fieldName) { return Reflect.get(originalEntity, fieldName); }, definitions_interface_1.UNDEF_SYMBOL);
        }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormDisabled = function (entity) {
    return R.isNil(entity) ? false : (wrapper_1.isDisabled(entity) || exports.isFormInProgress(entity));
};
/**
 * @stable [06.05.2020]
 * @param {IBaseExtendedFormEditableEntity<TEntity>} entity
 * @returns {boolean}
 */
exports.isFormChanged = function (entity) {
    return object_1.isObjectNotEmpty(select_1.Selectors.formEditableEntityChanges(entity));
};
/**
 * @stable [23.04.2020]
 * @param {IFormProps<TEntity>} entity
 * @returns {boolean}
 */
exports.isFormDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return (wrapper_1.isAlwaysDirty(entity) || cond_1.ifNotNilThanValue(select_1.selectForm(entity), function (form) { return wrapper_1.isDirty(form); }, false)); }, false);
};
/**
 * @stable [23.04.2020]
 * @param {IFormProps<TEntity>} entity
 * @returns {boolean}
 */
exports.isFormTouched = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return cond_1.ifNotNilThanValue(select_1.selectForm(entity), function (form) { return wrapper_1.isTouched(form); }, false); }, false);
};
/**
 * @stable [16.01.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormValid = function (entity) {
    return wrapper_1.isValid(entity) && wrapper_1.isValid(select_1.selectForm(entity));
}; // Redux or auto validation
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormInProgress = function (entity) {
    return wrapper_1.inProgress(mapper_1.selectEditableEntity(entity));
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} formEntity
 * @param {IGenericFieldEntity} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldReadOnly = function (formEntity, fieldProps) {
    return nvl_1.nvl(cond_1.ifNotNilThanValue(fieldProps, function () { return fieldProps.readOnly; }), cond_1.ifNotNilThanValue(formEntity, function () { return formEntity.readOnly; })) === true;
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps} formProps
 * @param {IGenericFieldEntity} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldDisabled = function (formProps, fieldProps) {
    return R.isNil(fieldProps.disabled) ? exports.isFormDisabled(formProps) : wrapper_1.isDisabled(fieldProps);
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps} formProps
 * @param {IGenericFieldEntity} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldChangeable = function (formProps, fieldProps) {
    return R.isNil(fieldProps.changeable) ? wrapper_1.isChangeable(formProps) : wrapper_1.isChangeable(fieldProps);
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @returns {boolean}
 */
exports.isFormSubmittable = function (formProps) {
    return exports.isFormValid(formProps)
        && exports.isFormDirty(formProps)
        && !exports.isFormDisabled(formProps);
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @returns {boolean}
 */
exports.isFormResettable = function (formProps) {
    return wrapper_1.isAlwaysResettable(formProps)
        || (exports.isFormDirty(formProps)
            && !exports.isFormDisabled(formProps));
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @param {ITabProps} tab
 * @returns {boolean}
 */
exports.isFormTabActive = function (formProps, tab) {
    return tab_1.isTabActive(select_1.selectForm(formProps), tab);
};
//# sourceMappingURL=form.js.map