"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var definitions_interface_1 = require("../definitions.interface");
var filter_1 = require("./filter");
var cond_1 = require("./cond");
var select_1 = require("./select");
/**
 * @stable [06.05.2020]
 * @mapper-generic
 *
 * @param {string} sectionName
 * @returns {ISectionNameWrapper}
 */
var mapSectionName = function (sectionName) {
    return filter_1.defValuesFilter({ sectionName: sectionName });
};
/**
 * @stable [06.05.2020]
 * @mapper-generic
 *
 * @param {TList} list
 * @returns {IListWrapper<TList>}
 */
var mapList = function (list) {
    return filter_1.defValuesFilter({ list: list });
};
/**
 * @stable [06.05.2020]
 * @mapper-generic
 *
 * @param {ISectionNameWrapper} wrapper
 * @returns {ISectionNameWrapper}
 */
var mapSectionNameWrapper = function (wrapper) { return mapSectionName(select_1.Selectors.sectionName(wrapper)); };
/**
 * @stable [06.05.2020]
 * @mapper-generic
 *
 * @param {IListWrapperEntity} wrapper
 * @returns {IListWrapperEntity}
 */
var mapListWrapperEntity = function (wrapper) { return mapList(select_1.Selectors.list(wrapper)); };
/**
 * @stable [05.05.2020]
 * @mapper-generic
 *
 * @param {IGenericPagedEntity} entity
 * @returns {IGenericPagedEntity}
 */
var mapPagedEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    page: entity.page,
    pageSize: entity.pageSize,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [06.05.2020]
 * @mapper-generic
 *
 * @param {IGenericLifeCycleEntity} entity
 * @returns {IGenericLifeCycleEntity}
 */
var mapLifeCycleEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    touched: entity.touched,
    progress: entity.progress,
    error: entity.error,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [05.05.2020]
 * @mapper-generic
 *
 * @param {IGenericPaginatedEntity} entity
 * @returns {IGenericPaginatedEntity}
 */
var mapPaginatedEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter(__assign({}, mapPagedEntity(entity), { lockPage: entity.lockPage, totalAmount: entity.totalAmount, totalCount: entity.totalCount })); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [06.05.2020]
 * @mapper-generic
 *
 * @param {IGenericPaginatedLifeCycleEntity} entity
 * @returns {IGenericPaginatedLifeCycleEntity}
 */
var mapPaginatedLifeCycleEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return (__assign({}, mapLifeCycleEntity(entity), mapPaginatedEntity(entity))); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [06.05.2020]
 */
var GenericMappers = /** @class */ (function () {
    function GenericMappers() {
    }
    GenericMappers.listWrapperEntity = mapListWrapperEntity;
    GenericMappers.pagedEntity = mapPagedEntity;
    GenericMappers.paginatedEntity = mapPaginatedEntity;
    GenericMappers.paginatedLifeCycleEntity = mapPaginatedLifeCycleEntity;
    GenericMappers.sectionNameWrapper = mapSectionNameWrapper;
    return GenericMappers;
}());
exports.GenericMappers = GenericMappers;
//# sourceMappingURL=mapper-generic.js.map