"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var filter_1 = require("./filter");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var type_1 = require("./type");
var entity_1 = require("./entity");
var nvl_1 = require("./nvl");
var wrapper_1 = require("./wrapper");
var select_1 = require("./select");
var mapper_generic_1 = require("./mapper-generic");
var mapper_component_1 = require("./mapper-component");
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
exports.selectTransportWrapperToken = function (entity) {
    return select_1.selectToken(select_1.selectTransport(entity));
};
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string[]}
 */
exports.selectTransportWrapperQueue = function (entity) {
    return select_1.selectQueue(select_1.selectTransport(entity));
};
/**
 * @stable [13.02.2020]
 * @param {TErrorWrapper} entity
 * @returns {TResult}
 */
exports.selectError = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.error;
};
/**
 * @stable [29.02.2020]
 * @param {IExtendedFormEditableEntity<TEntity extends IEntity>} wrapper
 * @returns {IGenericEditableEntity<TEntity extends IEntity>}
 */
exports.selectEditableEntity = function (wrapper) {
    return select_1.selectForm(wrapper);
};
/**
 * TODO
 * @deprecated
 */
exports.selectListEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.list; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [13.02.2020]
 * @param {IEffectsAction} action
 * @returns {TResult}
 */
exports.selectErrorFromAction = function (action) { return exports.selectError(action); };
/**
 * @stable [10.02.2020]
 * @param {ITabPanelWrapperEntity} entity
 * @returns {IGenericTabPanelEntity}
 */
exports.selectTabPanelEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.tabPanel;
};
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
exports.mapEntityId = function (id) {
    return filter_1.defValuesFilter({ id: id });
};
/**
 * @stable [29.01.2020]
 * @param {boolean} waitingForOptions
 * @returns {IWaitingForOptionsWrapper}
 */
exports.mapWaitingForOptions = function (waitingForOptions) {
    return filter_1.defValuesFilter({ waitingForOptions: waitingForOptions });
};
/**
 * @stable [28.01.2020]
 * @param {TValue} options
 * @returns {IOptionsWrapper<TValue>}
 */
exports.mapOptions = function (options) {
    return filter_1.defValuesFilter({ options: options });
};
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionsEntity} directions
 * @returns {ISortDirectionsWrapperEntity}
 */
exports.mapSortDirectionsWrapperEntity = function (directions) {
    return filter_1.defValuesFilter({ directions: directions });
};
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
exports.mapIdentifiedEntity = function (entity) {
    return exports.mapEntityId(select_1.selectEntityId(entity));
};
/**
 * @stable [10.02.2020]
 * @param {IGenericTabPanelEntity} tabPanel
 * @returns {ITabPanelWrapperEntity}
 */
exports.mapTabPanelEntity = function (tabPanel) {
    return filter_1.defValuesFilter({ tabPanel: tabPanel });
};
/**
 * @stable [21.11.2019]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
exports.mapTabPanelWrapperEntity = function (tabPanelWrapperEntity) {
    return exports.mapTabPanelEntity(exports.selectTabPanelEntity(tabPanelWrapperEntity));
};
/**
 * @stable [30.03.2020]
 * @param {TUser} user
 * @returns {IUserWrapper<TUser>}
 */
exports.mapUser = function (user) {
    return filter_1.defValuesFilter({ user: user });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} stack
 * @returns {IStackWrapper<TValue>}
 */
exports.mapStack = function (stack) {
    return filter_1.defValuesFilter({ stack: stack });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} notification
 * @returns {INotificationWrapper<TValue>}
 */
exports.mapNotification = function (notification) {
    return filter_1.defValuesFilter({ notification: notification });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} layout
 * @returns {ILayoutWrapper<TValue>}
 */
exports.mapLayout = function (layout) {
    return filter_1.defValuesFilter({ layout: layout });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} channel
 * @returns {IChannelWrapper<TValue>}
 */
exports.mapChannel = function (channel) {
    return filter_1.defValuesFilter({ channel: channel });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} transport
 * @returns {ITransportWrapper<TValue>}
 */
exports.mapTransport = function (transport) {
    return filter_1.defValuesFilter({ transport: transport });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} dictionaries
 * @returns {IDictionariesWrapper<TValue>}
 */
exports.mapDictionaries = function (dictionaries) {
    return filter_1.defValuesFilter({ dictionaries: dictionaries });
};
/**
 * @stable [12.10.2019]
 * @param {boolean} disabled
 * @returns {IDisabledWrapper}
 */
exports.mapDisabled = function (disabled) {
    return filter_1.defValuesFilter({ disabled: disabled });
};
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
exports.mapQuery = function (query) { return filter_1.defValuesFilter({ query: query }); };
/**
 * @stable [29.02.2020]
 * @param {TEntity} filter
 * @returns {IFilterWrapper<TEntity>}
 */
exports.mapFilter = function (filter) {
    return filter_1.defValuesFilter({ filter: filter });
};
/**
 * @stable [26.03.2020]
 * @param {TForm} form
 * @returns {IFormWrapper<TForm>}
 */
exports.mapForm = function (form) {
    return filter_1.defValuesFilter({ form: form });
};
/**
 * @stable [12.04.2020]
 * @param {TActiveValue} activeValue
 * @returns {IActiveValueWrapper<TActiveValue>}
 */
exports.mapActiveValue = function (activeValue) {
    return filter_1.defValuesFilter({ activeValue: activeValue });
};
/**
 * @stable [29.02.2020]
 * @param {IGenericActiveQueryEntity} filter
 * @returns {IQueryFilterEntity}
 */
exports.mapQueryFilterEntity = function (filter) { return exports.mapFilter(filter); };
/**
 * TODO
 * @deprecated Use mapForm
 */
exports.mapEditableEntity = function (form) {
    return filter_1.defValuesFilter({ form: form });
};
/**
 * @stable [04.05.2020]
 * @mapper
 *
 * @param {IGenericSelectableHoveredEntity} entity
 * @returns {IGenericSelectableHoveredEntity}
 */
var mapSelectableHoveredEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    hovered: entity.hovered,
    selectable: entity.selectable,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
exports.mapSortDirectionEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    index: entity.index,
    direction: entity.direction,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [05.05.2020]
 * @mapper
 *
 * @param {IGenericPaginatedEntity} entity
 * @param {number} pageSize
 * @returns {IGenericPagedEntity}
 */
var mapPaginatedEntityAsPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return cond_1.ifNotNilThanValue(entity, function () { return mapper_generic_1.GenericMappers.pagedEntity({
        page: entity.lockPage ? entity.page : definitions_interface_1.FIRST_PAGE,
        pageSize: pageSize,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [12.10.2019]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
exports.mapDisabledProgressWrapper = function (entity) {
    return exports.mapDisabled(wrapper_1.inProgress(entity));
};
/**
 * @stable [12.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
exports.mapDisabledProgressListWrapperEntity = function (listWrapperEntity) {
    return exports.mapDisabledProgressWrapper(select_1.selectList(listWrapperEntity));
};
/**
 * @stable [05.05.2020]
 * @mapper
 *
 * @param {IListWrapperEntity} entity
 * @param {number} pageSize
 * @returns {IGenericPagedEntity}
 */
var mapListWrapperEntityAsPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return mapPaginatedEntityAsPagedEntity(select_1.selectList(entity), pageSize);
};
/**
 * @stable [30.03.2020]
 * @param {IUserWrapperEntity<TEntity>} wrapper
 * @returns {IUserWrapperEntity<TEntity>}
 */
exports.mapUserWrapperEntity = function (wrapper) {
    return exports.mapUser(select_1.selectUser(wrapper));
};
/**
 * @stable [30.03.2020]
 * @param {IStackWrapperEntity<TEntity>} wrapper
 * @returns {IStackWrapperEntity<TEntity>}
 */
exports.mapStackWrapperEntity = function (wrapper) {
    return exports.mapStack(select_1.selectStack(wrapper));
};
/**
 * @stable [14.04.2020]
 * @param {INotificationWrapperEntity<TEntity>} wrapper
 * @returns {INotificationWrapperEntity<TEntity>}
 */
exports.mapNotificationWrapperEntity = function (wrapper) {
    return exports.mapNotification(select_1.selectNotification(wrapper));
};
/**
 * @stable [14.04.2020]
 * @param {ILayoutWrapperEntity<TEntity>} wrapper
 * @returns {ILayoutWrapperEntity<TEntity>}
 */
exports.mapLayoutWrapperEntity = function (wrapper) {
    return exports.mapLayout(select_1.selectLayout(wrapper));
};
/**
 * @stable [14.04.2020]
 * @param {IChannelWrapperEntity<TEntity>} wrapper
 * @returns {IChannelWrapperEntity<TEntity>}
 */
exports.mapChannelWrapperEntity = function (wrapper) {
    return exports.mapChannel(select_1.selectChannel(wrapper));
};
/**
 * @stable [28.03.2020]
 * @param {ITransportWrapperEntity<TTransport>} wrapper
 * @returns {ITransportWrapperEntity<TTransport>}
 */
exports.mapTransportWrapperEntity = function (wrapper) {
    return exports.mapTransport(select_1.selectTransport(wrapper));
};
/**
 * @stable [28.03.2020]
 * @param {IDictionariesWrapperEntity<TDictionaries>} wrapper
 * @returns {IDictionariesWrapperEntity<TDictionaries>}
 */
exports.mapDictionariesWrapperEntity = function (wrapper) {
    return exports.mapDictionaries(select_1.selectDictionaries(wrapper));
};
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {IActiveValueWrapper<TValue>}
 */
exports.mapActiveValueWrapper = function (wrapper) {
    return exports.mapActiveValue(select_1.selectActiveValue(wrapper));
};
/**
 * @stable [18.04.2020]
 * @param {IBaseExtendedEntity<TEntity>} extendedEntity
 * @returns {IBaseExtendedEntity<TEntity>}
 */
exports.mapBaseExtendedEntity = function (extendedEntity) {
    return filter_1.defValuesFilter({
        entity: select_1.selectEntity(extendedEntity),
        originalEntity: select_1.selectOriginalEntity(extendedEntity),
    });
};
/**
 * @stable [17.04.2020]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IExtendedEntity<TEntity>}
 */
exports.mapExtendedEntity = function (extendedEntity) {
    return filter_1.defValuesFilter(__assign({}, exports.mapBaseExtendedEntity(extendedEntity), { changes: select_1.selectChanges(extendedEntity), entityId: extendedEntity.entityId, newEntity: extendedEntity.newEntity }));
};
/**
 * @stable [05.04.2020]
 * @param {IFormEditableEntity<TEntity>} wrapper
 * @returns {IFormEditableEntity<TEntity>}
 */
exports.mapFormEditableEntity = function (wrapper) {
    return exports.mapForm(select_1.selectForm(wrapper));
};
/**
 * @stable [17.04.2020]
 * @param {TEntity} entity
 * @param {IGenericEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapEnhancedExtendedEntity = function (entity, editableEntity) {
    var originalEntity;
    var newEntity = entity_1.isNewEntity(entity);
    var changes = select_1.selectChanges(editableEntity) || {};
    var defaultChanges = select_1.selectDefaultChanges(editableEntity);
    cond_1.ifNotNilThanValue(nvl_1.nvl(defaultChanges, entity), function () { return (originalEntity = __assign({}, defaultChanges, entity)); });
    return exports.mapExtendedEntity({
        changes: changes,
        entity: __assign({}, originalEntity, changes),
        entityId: cond_1.orUndef(!newEntity, function () { return entity.id; }),
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @stable [25.12.2019]
 * @param {IGenericEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapNewExtendedEntity = function (editableEntity) {
    return exports.mapEnhancedExtendedEntity(null, editableEntity);
};
/**
 * @stable [26.04.2020]
 * @param {TEntity} entity
 * @param {IGenericEditableEntity<TEntity>} editableEntity
 * @returns {IExtendedFormEditableEntity<TEntity>}
 */
exports.mapExtendedFormEditableEntity = function (entity, editableEntity) {
    return (__assign({}, exports.mapForm(editableEntity), exports.mapEnhancedExtendedEntity(entity, editableEntity)));
};
/**
 * @stable [26.04.2020]
 * @param {IGenericEditableEntity<TEntity>} editableEntity
 * @returns {IExtendedFormEditableEntity<TEntity>}
 */
exports.mapNewExtendedFormEditableEntity = function (editableEntity) {
    return exports.mapExtendedFormEditableEntity(null, editableEntity);
};
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IApiEntity<TEntity>}
 */
exports.mapApiEntity = function (extendedEntity) {
    var changes = extendedEntity.changes, entity = extendedEntity.entity, originalEntity = extendedEntity.originalEntity;
    var entityId = select_1.selectEntityId(entity);
    var newEntity = R.isNil(entityId);
    return filter_1.defValuesFilter({
        changes: changes,
        diff: newEntity ? entity : changes,
        entity: entity,
        entityId: entityId,
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IGenericEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapListSelectedExtendedEntity = function (listWrapper, editableEntity) {
    return exports.mapEnhancedExtendedEntity(select_1.selectListSelectedEntity(listWrapper), editableEntity);
};
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterEntity} queryFilter
 * @returns {IQueryFilterEntity}
 */
exports.mapQueryFilterWrapperEntity = function (queryFilter) {
    return exports.mapQueryFilterEntity(select_1.selectFilter(queryFilter));
};
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterEntity} entity
 * @returns {IQueryWrapper}
 */
exports.mapFilterWrapperQuery = function (entity) {
    return exports.mapQuery(select_1.selectFilterEntityQuery(entity));
};
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
exports.mapActionsDisabled = function (actionsDisabled) {
    return filter_1.defValuesFilter({ actionsDisabled: actionsDisabled });
};
/**
 * @stable [22.04.2020]
 * @param {IProgressWrapper} progressWrapper
 * @returns {IActionsDisabledWrapper}
 */
exports.mapProgressWrapperActionsDisabled = function (progressWrapper) {
    return exports.mapActionsDisabled(wrapper_1.inProgress(progressWrapper));
};
/**
 * @stable [04.04.2020]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IActionsDisabledWrapper}
 */
exports.mapListWrapperActionsDisabled = function (listWrapper) {
    return exports.mapProgressWrapperActionsDisabled(select_1.selectList(listWrapper));
};
/**
 * @stable [11.10.2019]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
exports.mapSelectOptions = function (data) {
    return cond_1.ifNotNilThanValue(data, function (entities) { return ([].concat(entities)
        .map(function (entity) { return filter_1.defValuesFilter({
        value: select_1.selectEntityId(entity),
        label: entity.name,
        disabled: entity.disabled,
        rawData: entity,
    }); })); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => AnyT} accessor
 * @returns {Array<ISelectOptionEntity<TEntity>>}
 */
exports.selectDictionaryEntityOptions = function (dictionaryEntity, accessor) {
    return exports.mapSelectOptions(cond_1.ifNotNilThanValue(select_1.selectData(dictionaryEntity), function (data) { return type_1.isFn(accessor) ? accessor(data) : data; }));
};
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @returns {boolean}
 */
exports.selectDictionaryEntityLoading = function (dictionaryEntity) {
    return wrapper_1.isLoading(dictionaryEntity);
};
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: TEntity[]) => TResult} accessor
 * @returns {IGenericBaseSelectEntity}
 */
exports.mapDictionaryEntityField = function (dictionaryEntity, accessor) {
    return (__assign({}, exports.mapWaitingForOptions(exports.selectDictionaryEntityLoading(dictionaryEntity)), exports.mapOptions(exports.selectDictionaryEntityOptions(dictionaryEntity, accessor))));
};
/**
 * @stable [22.04.2020]
 * @param {INamedEntity} entity
 * @returns {IExtendedLabeledValueEntity}
 */
exports.mapExtendedLabeledValueEntity = function (entity) {
    return filter_1.defValuesFilter({
        value: entity.id,
        label: entity.name || String(entity.id),
        rawData: entity,
    });
};
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasQueueOperations = function (queue) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return !R.isEmpty(R.intersection(queue, operations.map(function (operation) { return (type_1.isString(operation)
        ? operation
        : operation.id); })));
};
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasTransportWrapperQueueOperations = function (entity) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return exports.hasQueueOperations.apply(void 0, [exports.selectTransportWrapperQueue(entity)].concat(operations));
};
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationInProgress = function (entity) { return wrapper_1.inProgress(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.doesApplicationErrorExist = function (entity) { return wrapper_1.doesErrorExist(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationMessageVisible = function (entity) {
    return exports.isApplicationInProgress(entity) || exports.doesApplicationErrorExist(entity) || !wrapper_1.isReady(entity);
};
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IGenericStackEntity}
 */
exports.selectStackEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.stack; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [18.12.2019]
 * @param {IGenericStackEntity} entity
 * @returns {IStackItemEntity[]}
 */
exports.selectStackItemEntities = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function (data) { return data.stack; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackItemEntity[]}
 */
exports.selectStackWrapperItemEntities = function (entity) {
    return exports.selectStackItemEntities(exports.selectStackEntity(entity));
};
/**
 * @stable [14.04.2020]
 * @param {IGenericStoreEntity<TDictionaries>} entity
 * @returns {IGenericStoreEntity<TDictionaries>}
 */
exports.mapStoreEntity = function (entity) {
    return (__assign({}, exports.mapChannelWrapperEntity(entity), exports.mapDictionariesWrapperEntity(entity), exports.mapLayoutWrapperEntity(entity), exports.mapNotificationWrapperEntity(entity), mapper_generic_1.GenericMappers.sectionNameWrapper(entity), exports.mapStackWrapperEntity(entity), exports.mapTransportWrapperEntity(entity), exports.mapUserWrapperEntity(entity)));
};
/**
 * @component-props-mapper
 * @stable [18.04.2020]
 *
 * @param {IBaseExtendedFormEditableEntity<TEntity>} props The props are defined according to "Liskov substitution principle"
 * @returns {IBaseExtendedFormEditableEntity<TEntity>}
 */
exports.mapFormProps = function (props) {
    return (__assign({}, exports.mapFormEditableEntity(props), exports.mapBaseExtendedEntity(props)));
};
/**
 * @container-props-mapper
 * @stable [18.04.2020]
 *
 * @param {IFormContainerProps} props
 * @returns {IFormContainerProps}
 */
exports.mapFormContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), exports.mapFormProps(props)));
};
/**
 * @container-props-mapper
 * @stable [23.04.2020]
 *
 * @param {IFilterFormDialogContainerProps} props
 * @returns {IFilterFormDialogContainerProps}
 */
exports.mapFilterFormDialogContainerProps = function (props) {
    return exports.mapFormContainerProps(props);
};
/**
 * @container-props-mapper
 * @stable [11.04.2020]
 *
 * @param {IListContainerProps} props
 * @returns {IListContainerProps}
 */
exports.mapListContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), mapper_generic_1.GenericMappers.listWrapperEntity(props)));
};
/**
 * @container-props-mapper
 * @stable [13.04.2020]
 *
 * @param {IFormTabPanelContainerProps} props
 * @returns {IFormTabPanelContainerProps}
 */
exports.mapFormTabPanelContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), exports.mapFormEditableEntity(props)));
};
/**
 * @container-props-mapper
 * @stable [23.04.2020]
 *
 * @param {IToolbarToolsContainerProps & IListContainerProps} props
 * @param {IGenericEditableEntity} editableEntity
 * @returns {IToolbarToolsContainerProps}
 */
exports.mapToolbarToolsListContainerProps = function (props, editableEntity) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), { toolbarTools: __assign({}, exports.mapListWrapperActionsDisabled(props), { activeActions: nvl_1.nvl(R.isNil(editableEntity)
                ? select_1.selectFormActiveFilterToolbarTools(props)
                : select_1.selectActiveFilterToolbarToolsByEditableEntity(editableEntity), []) }) }));
};
/**
 * @container-props-mapper
 * @stable [23.04.2020]
 *
 * @param {IFormEditableEntity<TEntity>} props
 * @param {IGenericContainer} proxyContainer
 * @returns {IUnsavedFormChangesDialogContainerProps}
 */
exports.mapUnsavedFormChangesDialogContainerProps = function (props, proxyContainer) {
    return ({
        dialogConfiguration: exports.mapFormEditableEntity(props),
        proxyContainer: proxyContainer,
    });
};
/**
 * @stable [05.05.2020]
 */
var Mappers = /** @class */ (function () {
    function Mappers() {
    }
    Mappers.listWrapperEntity = mapper_generic_1.GenericMappers.listWrapperEntity;
    Mappers.listWrapperEntityAsPagedEntity = mapListWrapperEntityAsPagedEntity;
    Mappers.pagedEntity = mapper_generic_1.GenericMappers.pagedEntity;
    Mappers.pageToolbarContainerProps = mapper_component_1.ComponentMappers.pageToolbarContainerProps;
    Mappers.pageToolbarContainerPropsAsPageToolbarProps = mapper_component_1.ComponentMappers.pageToolbarContainerPropsAsPageToolbarProps;
    Mappers.pageToolbarProps = mapper_component_1.ComponentMappers.pageToolbarProps;
    Mappers.paginatedEntity = mapper_generic_1.GenericMappers.paginatedEntity;
    Mappers.sectionNameWrapper = mapper_generic_1.GenericMappers.sectionNameWrapper;
    Mappers.selectableHoveredEntity = mapSelectableHoveredEntity;
    return Mappers;
}());
exports.Mappers = Mappers;
//# sourceMappingURL=mapper.js.map