"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var type_1 = require("./type");
/**
 * @stable [18.04.2020]
 * @param {AnyT} o
 * @returns {boolean}
 */
exports.isObjectNotEmpty = function (o) { return !R.isNil(o) && !R.isEmpty(o); };
/**
 * @stable [18.04.2020]
 * @param {AnyT} o
 * @returns {boolean}
 */
exports.isObjectEmpty = function (o) { return !exports.isObjectNotEmpty(o); };
/**
 * @stable [18.03.2020]
 * @param {AnyT} o
 * @returns {boolean}
 */
exports.isStringNotEmpty = function (o) { return type_1.isString(o) && exports.isObjectNotEmpty(o); };
/**
 * @stable [20.03.2019]
 * @param {AnyT} current
 * @param {AnyT} previous
 * @returns {boolean}
 */
exports.isCurrentValueNotEqualPreviousValue = function (current, previous) {
    return exports.isObjectNotEmpty(current) && !R.equals(current, previous);
};
/**
 * @stable [25.11.2019]
 * @param {TValue} object
 * @returns {TValue}
 */
exports.buildUndefValuesObject = function (object) {
    return exports.mergeObjectsArray(object, function () { return definitions_interface_1.UNDEF; });
};
/**
 * @stable [17.04.2020]
 * @param {TValue} object
 * @param {(o, key) => any} mergeFn
 * @returns {TValue}
 */
exports.mergeObjectsArray = function (object, mergeFn) {
    if (mergeFn === void 0) { mergeFn = function (o, key) { return o[key]; }; }
    return R.isNil(object)
        ? object
        : R.mergeAll(Object.keys(object).map(function (key) {
            var _a;
            return (_a = {}, _a[key] = mergeFn(object, key), _a);
        }));
};
//# sourceMappingURL=object.js.map