"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var definitions_interface_1 = require("../definitions.interface");
var util_1 = require("../util");
/**
 * @stable [05.05.2020]
 * @param {IGenericPaginatedEntity} entity
 * @returns {number}
 */
exports.pageCursorFrom = function (entity) { return 1 + (entity.page - definitions_interface_1.FIRST_PAGE) * entity.pageSize; };
/**
 * @stable [05.05.2020]
 * @param {IGenericPaginatedEntity} entity
 * @returns {number}
 */
exports.pageCursorTo = function (entity) {
    return util_1.ifNotNilThanValue(entity.pageSize, function (pageSize) { return Math.min(entity.page * pageSize, entity.totalCount); });
};
/**
 * @stable [05.05.2020]
 * @param {IGenericPaginatedEntity} entity
 * @returns {number}
 */
exports.pagesCount = function (entity) { return Math.ceil(entity.totalCount / entity.pageSize); };
/**
 * @stable [05.05.2020]
 * @param {IGenericPaginatedEntity} entity
 * @returns {boolean}
 */
exports.isPageCursorInEndPosition = function (entity) {
    return exports.pageCursorTo(entity) === entity.totalCount;
};
/**
 * @stable [05.05.2020]
 * @param {IGenericPaginatedEntity} entity
 * @returns {boolean}
 */
exports.isPageCursorInStartPosition = function (entity) {
    return entity.page === definitions_interface_1.FIRST_PAGE;
};
/**
 * @stable [05.05.2020]
 * @param {IGenericPaginatedEntity} entity
 * @returns {boolean}
 */
exports.isPageable = function (entity) { return entity.totalCount > entity.pageSize; };
//# sourceMappingURL=page.js.map